/*____________________________________________________________________________*
 *=====[ Alberto Cavalin - 472802 STI - Prova finale laboratorio di SAS ]=====*
 *----------------------------------------------------------------------------*/

/* -- Punto 0.1 ------------------------------------------------------------- *
 * ---- Percorso della libreria nella quale salvare i datasets -------------- *
 * -------------------------------------------------------------------------- */
LIBNAME lib "c:\utenti";


/* -- Punto 0.2 ------------------------------------------------------------- *
 * ---- Acquisizione: "malattie-anagrafica veneto.txt" ---------------------- *
 * -------------------------------------------------------------------------- *
 * L'opzione "FIRSTOBS=2" fa in modo che i dati vengano letti  dalla  seconda *
 * riga in poi; "DELIMITER='&'" identifica il delimitatore delle osservazioni *
 * all'interno della riga; "DSD" fa in modo  che  due  separatori  affiancati *
 * identifichino un dato mancante.                                            *
 * -------------------------------------------------------------------------- */
DATA mal_ana_v;
    INFILE  "i:\lab2003\malattie-anagrafica veneto.txt"
            FIRSTOBS=2 DELIMITER='&' DSD;
    INPUT   codice eta peso altezza fumo sesso;
RUN;


/* -- Punto 0.3 ------------------------------------------------------------- *
 * ---- Acquisizione: "malattie veneto.txt" --------------------------------- *
 * -------------------------------------------------------------------------- *
 * L'opzione TRUNCOVER fa in modo che non venga terminata la lettura del file *
 * in caso di errori; innanzi tutto viene letto il codice dell'individuo dopo *
 * di che viene sospesa  la  lettura  per  la  creazione  di  un  vettore  di *
 * variabili allo scopo di sfruttarne le potenzialita' di indicizzazione  per *
 * le successive letture. Un ciclo in  questo  caso  risulta  particolarmente *
 * utile, in quanto usando il  salto  indicizzato  tamite  la  variabile  "i" *
 * e' possibile leggere tutte le variabili dicotomiche a mezzo  di  una  sola *
 * istruzione di INPUT. Il valore letto con "tmp" risulta poi pari all'indice *
 * che, passato al vettore "malattie", identifica  la  malattia  dalla  quale *
 * l'individuo e' affetto.                                                    *
 * -------------------------------------------------------------------------- */
DATA mal_v;
    INFILE  "i:\lab2003\malattie veneto.txt" TRUNCOVER;

    INPUT   codice 1-4  @;  /* lettura codice univoco */

    /* definizione delle variabili dicotomiche */
    ARRAY   malattie        /* vettore delle variabili dicotomiche */
            diabete ipertensione infarto angina mal_card bronchite asma allergie
            tumore ulcera calcoli cirrosi calcoli artrosi osteoporosi mal_nerv;

    /* inizializzazione delle variabili (0=niente malattia, 1=malattia) */
    DO i=1 TO 16 BY 1;      /* inizializzazione delle variabili dicotomiche */
        malattie(i)=0;
    END;

    /* lettura malattie dell'individuo */
    DO i=1 TO 17 BY 1;      /* inizio ciclo per la scansione delle colonne */
        INPUT   @(3+i*2)    /* salto alla colonna da leggere */
                tmp $ :2.   /* lettura variabile di due caratteri */
                @;          /* sospensione della lettura */
        j=tmp+0;            /* conversione da CHAR ad INT */
        IF j>0 THEN         /* l'indice del vettore deve variare da 1 a 16 */
            malattie(j)=1;  /* identificazione della malattia */
    END;

    DROP tmp i j;           /* eliminazione variabili temporanee */
RUN;


/* -- Punto 0.4 ------------------------------------------------------------- *
 * ---- Unione dei due datasets --------------------------------------------- * 
 * -------------------------------------------------------------------------- *
 * Prima di effettuare  l'unione  occorre  ordinare  per  codice  il  dataset *
 * "mal_ana_v"; il dataset "mal_v" invece, dopo un banale controllo,  risulta *
 * essere gia' ordinato.                                                      *
 * -------------------------------------------------------------------------- */
PROC SORT DATA=mal_ana_v OUT=mal_ana_v;
    BY codice;              /* ordinamento per codice del dataset */
RUN;

DATA lib.veneto;            /* unione per riga dei due datasets */
    MERGE   mal_ana_v
            mal_v;
    BY codice;
RUN;


/* -- Punto 1 --------------------------------------------------------------- *
 * ---- Proc FREQ e UNIVARIATE ---------------------------------------------- * 
 * -------------------------------------------------------------------------- *
 * Dall'analisi delle tabelle di frequenza prodotte dalla "PROC FREQ" si puo' *
 * notare che:                                                                *
 *      fumo (nel complesso l'81.14% degli individui non fuma attualmente)    *
 *      ----                                                                  *
 *        .il 67.68% non ha mai fumato                                        *
 *        .il 13.46% ha funamto in passato                                    *
 *        .il 18.86% fuma                                                     *
 *                                                                            *
 *      sesso (sotto questo aspetto il campione e' ben equilibrato)           *
 *      -----                                                                 *
 *        .il 48.99% sono maschi                                              *
 *        .il 51.01% sono femmine                                             *
 *                                                                            *
 *      malattie (nel complesso le malattie spaziano dal 97% al 99% come % di *
 *      --------  non contagio;in pratica una % molto bassa della popolazione * 
 *                risulta essere malata)                                      *
 *        .la % minima e' dell'88.34%                                         *
 *        .la % massima e' dell'99.95%                                        *
 *                                                                            *
 * Dalle statistiche descrittive per variabili numeriche prodotte dalla "PROC *
 * FREQ" si puo' notare che:                                                  *
 *      eta                                                                   *
 *      ---                                                                   *
 *        .l'eta' media risulta sui 36.78 anni compiuti                       *
 *        .con uno scarto quadratico medio pari a 21.04                       *
 *        .con un range che va da 0 a 95 anni                                 *
 *                                                                            *
 *      peso                                                                  *
 *      ----                                                                  *
 *        .il peso medio risulta sui 62.57 Kg                                 *
 *        .con uno scarto quadratico medio pari a 19.11                       *
 *        .con un range che va da 4 a 123 Kg                                  *
 *                                                                            *
 *      altezza                                                               *
 *      -------                                                               *
 *        .l'altezza media risulta sui 162.90 cm                              *
 *        .con uno scarto quadratico medio pari a 19.61                       *
 *        .con un range che va da 48 a 202 cm                                 *
 * -------------------------------------------------------------------------- */
PROC FREQ DATA=lib.veneto;
    TABLES  fumo sesso diabete ipertensione infarto angina mal_card bronchite
            asma allergie tumore ulcera calcoli cirrosi calcoli artrosi
            osteoporosi mal_nerv;
RUN;

PROC UNIVARIATE DATA=lib.veneto;
    VAR     eta
            peso
            altezza;
RUN;


/* -- Punto 2 --------------------------------------------------------------- *
 * ---- Variabile dicotomica e contatore ------------------------------------ * 
 * -------------------------------------------------------------------------- *
 * Dato che le variabili dicotomiche sono codificate tramite 0 e 1, il numero *
 * totale di malattie risulta essere la somma totale delle stesse.            *
 * La variabile indicatrice "malato" invece viene inizializzata  tramite  una *
 * banale condizione effettuate sulla variabile "nmal" appena creata.         *
 * -------------------------------------------------------------------------- */
DATA lib.veneto;
    SET lib.veneto;
    
    /* calcolo del numero di malattie */
    nmal=SUM(diabete,ipertensione,infarto,angina,mal_card,bronchite,asma,
             allergie,tumore,ulcera,calcoli,cirrosi,calcoli,artrosi,
             osteoporosi,mal_nerv);

    IF nmal>0 THEN          /* var dicotomica: 0=non malato, 1=malato */
        malato=1;
    ELSE
        malato=0;
RUN;


/* -- Punto 3 --------------------------------------------------------------- *
 * ---- Eta' VS numero di malattie ------------------------------------------ * 
 * -------------------------------------------------------------------------- *
 * La variabile "eta" e' stata  classificata  in  5  classi  di  15  anni  di *
 * ampiezza ciascuna; la variabile "nmal" invece e' stata classificata  in  5 *
 * classi, dove l'ultima  rappresenta  il  caso  ">=4 malattie",  perche'  il *
 * numero di individui con piu' di 4 malattie e' molto esiguo e  ho  ritenuto *
 * conveniente il raggruppamento con la classe "=4".                          *
 * Dal test chi-quadro della PROC FREQ si  puo'  notare  che  il  livello  di *
 * significativita' osservato e' circa 0, e quindi esiste una dipendenza  tra *
 * le due variabili.                                                          *
 * -------------------------------------------------------------------------- */
DATA veneto_eta_vs_mal;
    SET lib.veneto;
    KEEP classe_eta classe_nmal;
    SELECT;
        WHEN (eta>= 0 & eta<15) classe_eta=' 0-14';
        WHEN (eta>=15 & eta<30) classe_eta='15-29';
        WHEN (eta>=30 & eta<45) classe_eta='30-44';
        WHEN (eta>=45 & eta<60) classe_eta='45-59';
        WHEN (eta>=60)          classe_eta='60 up';
    END;

    SELECT;
        WHEN (nmal= 0) classe_nmal='0';
        WHEN (nmal= 1) classe_nmal='1';
        WHEN (nmal= 2) classe_nmal='2';
        WHEN (nmal= 3) classe_nmal='3';
        OTHERWISE classe_nmal='4 up';
    END;
RUN;

PROC FREQ DATA=veneto_eta_vs_mal;
    TABLES  classe_eta*classe_nmal
            /CHISQ;
RUN;


/* -- Punto 4 --------------------------------------------------------------- *
 * ---- Sesso VS Mal_nerv & Fumo VS Bronchite ------------------------------- * 
 * -------------------------------------------------------------------------- *
 * Dal test chi-quadro della PROC FREQ si  puo'  notare  che  il  livello  di *
 * significativita' osservato e' molto basso in entrambe le analisi,  e  cio' *
 * significa che esiste una dipendenza tra le  due  variabili  (tra  sesso  e *
 * mal_nerv; e tra fumo e bronchite).                                         *
 * -------------------------------------------------------------------------- */
PROC FREQ DATA=lib.veneto;
    TABLES  sesso*mal_nerv
            fumo*bronchite
            /CHISQ;
RUN;


/* -- Punto 5 --------------------------------------------------------------- *
 * ---- Correlazione -------------------------------------------------------- * 
 * -------------------------------------------------------------------------- *
 * Con la prima PROC CORR le correlazioni tra le tre variabili sono buone:    *
 *      eta & altezza  : 0.38                                                 *
 *      eta & peso     : 0.53                                                 *
 *      altezza & peso : 0.82                                                 *
 * Con la seconda, le correlazioni salgono vertiginosamente tutte sul ~0.9.   *
 * Con la terza, le correlazioni salgono tutte ancora di ~0.02 punti.         *
 * Con la quarta, le  correlazioni  si  abbassano  e  diventano  simili  alla *
 * seconda.                                                                   *
 * -------------------------------------------------------------------------- */
PROC CORR DATA=lib.veneto;
    VAR     eta altezza peso;
RUN;

PROC CORR DATA=lib.veneto;
    VAR     eta altezza peso;
    WHERE   eta<21;
RUN;

PROC CORR DATA=lib.veneto;
    VAR     eta altezza peso;
    WHERE   eta<21 & sesso=1;
RUN;

PROC CORR DATA=lib.veneto;
    VAR     eta altezza peso;
    WHERE   eta<21 & sesso=2;
RUN;


/* -- Punto 6 --------------------------------------------------------------- *
 * ---- Regressione --------------------------------------------------------- * 
 * -------------------------------------------------------------------------- *
 * Il modello ha un coefficiente R^2 pari a  0.89  il  quale  indica  che  la *
 * scelta effettuate e' molto buona, inoltre il test t per  la  nullita'  dei *
 * parametri risulta in ambedue i casi con  un  livello  di  significativita' *
 * osservato di ~0, il che porta a rifiutare l'ipotesi nulla                  *
 * -------------------------------------------------------------------------- */
PROC REG DATA=lib.veneto;
    WHERE   eta<21;
    MODEL   altezza=eta peso;
    OUTPUT  OUT=result PREDICTED=pred RESIDUAL=res;
RUN;
QUIT;

/* -- Punto 7 --------------------------------------------------------------- *
 * ---- Creazione sub-set di lib.veneto ------------------------------------- * 
 * -------------------------------------------------------------------------- *
 * L'istruzione WHERE filtra gli individui  in  base  all'eta',  mentre  KEEP *
 * elimina tutte le variabili ad esclusione di codice, eta e sesso            *
 * -------------------------------------------------------------------------- */
DATA veneto_subset;
    SET     lib.veneto;
    WHERE   malato=1;
    KEEP    codice eta sesso;
RUN;

