/*---------------------------Corso SAS - 2003---------------------------------*/
/* Mauro Malvestio - 473678/STI - malveo@milliways.stat.unipd.it              */
/* File : mauromalvestio finale.sas                                           */
/* Docente: Dott.ssa: Silvia Sartorelli                                       */

/*--------------------------Esercitazione Marzo 2003--------------------------*/

/*-Impostazione di un path per lib--------------------------------------------*/
LIBNAME lib 'c:\utenti\lab';

/*-Acquisizione : malattie-anagrafica veneto.txt------------------------------*/
/*-COMMENTO-------------------------------------------------------------------*/
/* Il seguente pezzo di codice crea un dataset permanente di nome :             
   lib.malattie_anagrafica_veneto, cominciando la lettura dalla seconda riga,   
   scegliendo come delimitatore il carattere '&' e indicando con l'opzione      
   DSD che due separatori consecutivi '&&' indicano un dato mancante          */
/*-CODICE---------------------------------------------------------------------*/
DATA lib.malattie_anagrafica_veneto;
INFILE 'i:\lab2003\malattie-anagrafica veneto.txt' FIRSTOBS=2 DELIMITER='&' DSD;
INPUT Codice Eta Peso Altezza Fumo Sesso;
RUN;

/*-Acquisizione : malattie veneto.txt-----------------------------------------*/
/*-COMMENTO-------------------------------------------------------------------*/
/* Il seguente pezzo di codice crea un dataset permanente : lib.malattie_veneto,
   prelevando i dati dal file malattie veneto.txt, l'opzione TRUNCOVER permette 
   una lettura corretta anche in presenza di dati mancanti, viene dichiarato e  
   definito tutto a 0 un vettore di 16 malattie che servir in fase di lettura  
   La lettura avviene in due passi per primo si acquisisce il Codice individuale
   tenendo bloccato il buffer tramite l'opzione di input @, viene reimpostato   
   l'array Malattie, si esporta dal buffer in v1 l'i-esima malattia tramite il  
   selettore (3+2i) [5,7,9,11,13,..,..], e viene imposta la corrispondente      
   variabile a 1 nel vettore Malattie, altrimenti (otherwise) si esce dal ciclo 
   con l'istruzione i = 16, al completamento dell'acquisizione si eliminino le  
   variabili temporanee i v1 j                                                */
/*-CODICE---------------------------------------------------------------------*/
DATA lib.malattie_veneto;
INFILE 'i:\lab2003\malattie veneto.txt' TRUNCOVER;
INPUT  Codice 1-4 @;
ARRAY Malattie (16) DIABETE IPERTENSIONE INFARTO ANGINA MALATTIE_CARDIACHE
                    BRONCHITE ASMA ALLERGIE TUMORE ULCERA CALCOLI CIRROSI
                    CALCOLI_RENALI ARTROSI OSTEOPOROSI MALATTIE_NERVOSE;
i = 1; j = 1;
DO WHILE ( j <= 16);
    Malattie(j) = 0;
    j = j+1;
END;
DO WHILE ( i <= 17);
    INPUT @(3+2*i) v1 $:2. @;
        Indice = v1+0;
        if Indice > 0 then
            Malattie(Indice) = 1;
    i = i + 1;
END; 
drop i v1 j;
RUN;

/*-MERGE : malattie-anagrafica veneto.txt + malattie veneto.txt---------------*/
/*-COMMENTO-------------------------------------------------------------------*/
/* Ordinamento tramite PROC SORT sull'attributo Codice nel file                 
   permanente lib.malattie_anagrafica_veneto, con successiva UNIONE con il file 
   permanente lib.malattie_veneto*/
/*-CODICE---------------------------------------------------------------------*/
PROC SORT DATA = lib.malattie_anagrafica_veneto 
          OUT = lib.malattie_anagrafica_veneto;
by Codice;
RUN;
/* DATA STEP contenente l'istruzione del passo di DATA MERGE                  */
DATA lib.veneto;
MERGE lib.malattie_anagrafica_veneto lib.malattie_veneto;
by Codice;
RUN;

/*-1--------------------------------------------------------------------------*/
/* Si producano le tabelle di frequenza semplici (per le variabili per cui hanno
   senso) e gli indicatori univariati (per le variabili per cui hanno senso)  */
/*-COMMENTO-------------------------------------------------------------------*/
/* Tramite la PROC FREQ si producono tabelle di frequenza semplici, in questo   
   caso per la variabili per cui hanno senso Fumo Sesso e le varie variabili    
   dicotomiche rappresentanti le malattie; la PROC UNIVARIATE produce gli       
   indicatori univariati per le variabili continue Et Peso Altezza             
   Fumo :
    1 -> il 67% na ha mai fumato
    2 -> il 13% ha fumato in passato
    3 -> il 18% fuma
   Sesso :
    Maschi  -> 48.99%
    Femmine -> 51.01%
    Con queste percentuali ben bilanciate, il campione diviene rappresentativo  
    di tutta la popolazione (cosa che si deve valutare attentamente!!!) 
   Malattie: 
    Date le percentuali la popolazione e pressoch sana, infatti certe
    malattie attecchiscono pochissimo percentuali vicine al 99%.
   Eta Peso Altezza : (Analisi Univariata)
    Dall'analisi dei Quantili (Definizione 5) si riscontrano valori di Quantile-
    Stima che coprono per intero tutta la popolazione.

                                                                              */

/*-CODICE---------------------------------------------------------------------*/
PROC FREQ DATA = lib.veneto;
TABLES Fumo Sesso DIABETE IPERTENSIONE INFARTO ANGINA MALATTIE_CARDIACHE 
        BRONCHITE ASMA ALLERGIE TUMORE ULCERA CALCOLI CIRROSI 
        CALCOLI_RENALI ARTROSI OSTEOPOROSI MALATTIE_NERVOSE;
RUN;
PROC UNIVARIATE DATA = lib.veneto;
VAR Eta Peso Altezza;
RUN;

/*-2--------------------------------------------------------------------------*/
/* Si creino due variabili : una variabile dicotomica che indichi la presenza di
   almeno una malattia cronica e una variabilile che indichi il numero di       
   malattie croniche per ciascun individuo                                    */
/*-COMMENTO-------------------------------------------------------------------*/
/* In questo segmento di codice viene creato un vettore di nome Malattie di     
   lunghezza 16 per gestire le malattie di ogni singolo soggetto il primo ciclo 
   conta le malattie di ongni soggetto sfruttando la codifica della malattia    
   stessa che puo essere o [0] o [1], la somma viene memorizzata nella variabile
   n_malattie; per realizzare la variabile indicatrice che indica la presenza di
   almeno una malattia cronica vado ad analizzare n_malattie se quest'ultima e a
   0 signfica che il soggetto i-esimo non presenta malattie croniche altrimenti 
   si, e quindi setto la variabile indicatore di conseguenza, al termine elimino
   la variabile temporanea di ciclo j                                         */
/*-CODICE---------------------------------------------------------------------*/
DATA lib.veneto;
SET lib.veneto;
ARRAY Malattie (16) DIABETE IPERTENSIONE INFARTO ANGINA MALATTIE_CARDIACHE
                    BRONCHITE ASMA ALLERGIE TUMORE ULCERA CALCOLI CIRROSI
                    CALCOLI_RENALI ARTROSI OSTEOPOROSI MALATTIE_NERVOSE;
j = 1;
n_malattie = 0;
DO WHILE ( j <= 16);
    n_malattie = n_malattie + Malattie(j);
    j = j+1;
END;
SELECT;
    when ( n_malattie = 0 )
        indicatrice = 0;
    otherwise 
        indicatrice = 1;
END;
DROP j;
RUN;

/*-3--------------------------------------------------------------------------*/
/* Dopo opportuni accorpamenti si produca una tabella di contingenza tra il     
   numero di malattie e la classe d'eta e se ne valuti l'eventuale              
   associazione ..............................................................*/
/*-COMMENTO-------------------------------------------------------------------*/
/* La suddivisione per la variabile Eta avviene tramite classi di lunghezza 10, 
   per discretizzare in decadi la vita di ciscun soggetto, analizzando il       
   livello di significativita dell'indice Chi-Quadrato (lso <= 10^-3) in output 
   dalla PROC FREQ si evince una dipendenza tra le variabili sotte esame      */
/*-CODICE---------------------------------------------------------------------*/
DATA lib.veneto2;
    SET lib.veneto;
    Eta = floor(Eta /10);
RUN;
PROC FREQ DATA = lib.veneto2;
    TABLES Eta * n_malattie / CHISQ;
RUN;

/*-4--------------------------------------------------------------------------*/
/* Si producano le tabelle di contingenza tra sesso e la presenza di malattie   
   nervose e tra l'abitudine al fumo e la presenza di bronchite e se ne valuti  
   l'associazione                                                             */
/*-COMMENTO-------------------------------------------------------------------*/
/* L'analisi frequentistica risultante dalla lettura delle tabelle di           
   contingenza evidenzia un associazione tra Sesso e Malattie Nervose           
   affermazione che viene giustificata dal livello di significativit del test  
   Chi-Quadrato
   Evidente e anche la relazione tra Fumo e Bronchite vista la bassa            
   significativit del test Chi-Quadrato                                      */
/*-CODICE---------------------------------------------------------------------*/
PROC FREQ DATA = lib.veneto;
    TABLES Sesso*indicatrice Fumo*BRONCHITE / CHISQ;
RUN;

/*-5--------------------------------------------------------------------------*/
/* Si calcoli e si valuti la correlazione tra et, altezza e perso prima sull'  
   intero dataset poi solo per gli individui di et inferiore a 21 anni, insieme
   e separatamente per mschi e femmine                                        */
/*-COMMENTO-------------------------------------------------------------------  
 - Nell intero dataset si osservano forti correlazioni                          
   [Altezza Peso] -> 0.82623
   [Et Peso]     -> 0.53653
   [Et Altezza]  -> 0.38917
 - Con la restrizione Et < 21 
   Si notano ancora forti correlazioni positive con variabili tra loro          
   direttamente proporzionali 
 - Analizzando i due Sessi in modo distinto
   La correlazione rimane ancora forte, anche se per il Sesso femminile tende a 
   diminuire                                                                  */
/*-CODICE---------------------------------------------------------------------*/
/*-Per Et Altezza Peso ------------------------------------------------------*/
PROC CORR DATA = lib.veneto;
    VAR Eta Altezza Peso;
RUN;
/*-Per Et Altezza Peso -con vincolo Et < 21---------------------------------*/
PROC CORR DATA = lib.veneto;
    WHERE eta < 21;
    VAR Eta Altezza Peso;
RUN;
/*-Per i Maschi - Sesso = 1-con vincolo Et < 21------------------------------*/
PROC CORR DATA = lib.veneto;
    WHERE eta < 21 & Sesso = 1;
    VAR Eta Altezza Peso;
RUN;
/* -Per le Femmine - Sesso = 2-con vincolo Et < 21---------------------------*/
PROC CORR DATA = lib.veneto;
    WHERE eta < 21 & Sesso = 2;
    VAR Eta Altezza Peso;
RUN;

/*-6--------------------------------------------------------------------------*/
/* Si proponga un modello di regressione per spiegare l'altezza degli individui 
   di eta inferiore a 21 anni                                                 */
/*-COMMENTO-------------------------------------------------------------------*/
/* Tramite la procedura PROC REG si produce un analisi di regressione usando    
   altezza come varibile risposta e (peso + et + fumo) come predittore lineare,
   l'indice R2 ci porta a dire che il nosto modello e adatto a descrivere la    
   situazione in esame, le variabili introdotte come regessori apportano tutte  
   un contributo alla spiegazione della variabile risposta altezza; anche se per
   la varibile fumo il test t per l'ipotesi di nullita del parametro risulta con
   livello di significativit inferiore a 0.0001                              */
/*-CODICE---------------------------------------------------------------------*/
PROC REG DATA = lib.veneto;
    WHERE eta < 21;
    MODEL altezza = peso eta fumo;
    OUTPUT OUT=result PREDICTED=pred RESIDUAL=res;
RUN;QUIT;

/*-7--------------------------------------------------------------------------*/
/* Si crei un dataset contenente solo il sesso e l'et degli individui effetti  
   da almeno una malattia                                                     */
/*-COMMENTO-------------------------------------------------------------------*/
/* Il seguente passo di data, reimposta il dataset con il precedente, esegue    
   una selezione per ottenere solo osservazioni in cui la variabile dicotomica  
   e a 1, e mantiene visibili solo le variabili Sesso e Et                   */
/*-CODICE---------------------------------------------------------------------*/
DATA lib.malattie;
    SET lib.veneto;
    WHERE indicatrice = 1;
    KEEP Sesso Eta;
RUN;
/* EOF */