LIBNAME lib 'M:\corsi\sas_silvia\libs';

/* ----------------------------------------------------------------------------
	Acquisizione dati
*/
DATA lib.pro;
	INFILE 'M:\corsi\sas_silvia\datasets\proteine.txt' FIRSTOBS=2;
	INPUT Country$ :15. RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg;
RUN;

/* ----------------------------------------------------------------------------
	Applico la procedura di raggruppamento; dalle prove risulta che i metodi
	complete, mcquitty, average e centroid e scegliendo il "taglio" a 4 gruppi,
	danno sostanzialmente gli stessi risultati
	-----
	METHOD: metodo del ricalcolo delle distanze ad ogni passo
	OUTREE: destinazione del dataset che servira' per una successiva procedura
		descrittiva
	VAR: indica le variabili quantitative sulle quali effettuare i conti
	ID: anziche' usare un numero identificativo, usa il valore della var indicata
*/
PROC CLUSTER DATA=lib.pro METHOD=COMPLETE OUTTREE=albero;
	VAR RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg;
	ID country;
RUN;
PROC TREE DATA=albero OUT=gruppi n=4 HORIZONTAL; RUN;

/* ----------------------------------------------------------------------------
	ordino rispetto al nome del paese per unire il dataset che contiene i
	gruppi a quello originale
*/
DATA gruppi;		/* rinominazione del nome scelto da SAS */
	SET gruppi;
	country=_NAME_;
	DROP _NAME_;
RUN;

PROC SORT DATA=gruppi OUT=gruppi;
	BY country;
RUN;

PROC SORT DATA=lib.pro OUT=lib.pro;
	BY country;
RUN;

DATA lib.pro;
	MERGE lib.pro gruppi;
	BY country;
RUN;

/* ----------------------------------------------------------------------------
	analisi differenziale delle variabili a seconda del gruppo di appartenenza
	del paese
	-----
	PLOT (...)*CLUSTER: confronta i boxplot con i gruppi
*/
PROC BOXPLOT DATA=lib.pro;
	PLOT (RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg)*CLUSTER;
	ID country;
RUN;

PROC SORT DATA=lib.pro OUT=lib.pro;
	BY CLUSTER;
RUN;

PROC MEANS DATA=lib.pro;	/* calcola un sottoinsieme degli indicatori univariati */
	VAR RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg;
	BY CLUSTER;
RUN;

/* ----------------------------------------------------------------------------
	Proc factor
*/
PROC FACTOR DATA=lib.pro NPLOT=3 SCREE r=v OUT=fact NFACTORS=3; 
	VAR RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg ; 
RUN;


PROC GPLOT DATA=fact;
	PLOT factor1*factor2 factor1*factor3 factor2*factor3;
RUN;

PROC ANOVA DATA=lib.pro;
	CLASS CLUSTER;
	MODEL RedMeat WhiteMeat Eggs Milk Fish Cereals Starch Nuts FrVeg=CLUSTER;
RUN;
